@@ -55,10 +55,10 @@ public:
      */
     void setReadOnlyDrop(bool readOnly);
 
-    virtual bool dropEvent(QAbstractItemView* view, const QDropEvent* e, const QModelIndex& droppedOn);
-    virtual Qt::DropAction accepts(const QDropEvent* e, const QModelIndex& dropIndex);
-    virtual QStringList mimeTypes() const;
-    virtual QMimeData* createMimeData(const QList<QModelIndex> &);
+    virtual bool dropEvent(QAbstractItemView* view, const QDropEvent* e, const QModelIndex& droppedOn) override;
+    virtual Qt::DropAction accepts(const QDropEvent* e, const QModelIndex& dropIndex) override;
+    virtual QStringList mimeTypes() const override;
+    virtual QMimeData* createMimeData(const QList<QModelIndex> &) override;
 
 Q_SIGNALS:
 
