@@ -380,8 +380,8 @@ ColumnPhotoConfigurationWidget::ColumnPhotoConfigurationWidget(TableViewShared*
                                                                QWidget* const parentWidget)
     : TableViewColumnConfigurationWidget(sharedObject, columnConfiguration, parentWidget),
       subColumn(ColumnPhotoProperties::SubColumnExposure),
-      selectorExposureTimeFormat(0),
-      selectorExposureTimeUnit(0)
+      selectorExposureTimeFormat(nullptr),
+      selectorExposureTimeUnit(nullptr)
 {
     ColumnPhotoProperties::getSubColumnIndex<ColumnPhotoProperties>(configuration.columnId, &subColumn);
 
@@ -439,7 +439,7 @@ void ColumnPhotoProperties::setConfiguration(const TableViewColumnConfiguration&
 {
     configuration = newConfiguration;
 
-    emit(signalAllDataChanged());
+    emit signalAllDataChanged();
 }
 
 void ColumnPhotoConfigurationWidget::slotUpdateUI()
