@@ -59,13 +59,13 @@ public:
 
     explicit Private()
       : copyDone(false),
-        title(0),
-        saveSettingsGroupBox(0),
-        fileTemplateQLineEdit(0),
-        savePtoCheckBox(0),
-        warningLabel(0),
-        errorLabel(0),
-        mngr(0)
+        title(nullptr),
+        saveSettingsGroupBox(nullptr),
+        fileTemplateQLineEdit(nullptr),
+        savePtoCheckBox(nullptr),
+        warningLabel(nullptr),
+        errorLabel(nullptr),
+        mngr(nullptr)
     {
     }
 
@@ -202,8 +202,8 @@ void PanoLastPage::checkFiles()
         {
             if (input != d->mngr->preProcessedMap()[input].preprocessedUrl)
             {
-                QString dir = input.toString(QUrl::RemoveFilename);
-                QUrl derawUrl(dir + d->mngr->preProcessedMap()[input].preprocessedUrl.fileName());
+                QString dir2 = input.toString(QUrl::RemoveFilename);
+                QUrl derawUrl(dir2 + d->mngr->preProcessedMap()[input].preprocessedUrl.fileName());
                 QFile derawFile(derawUrl.toString(QUrl::PreferLocalFile));
                 rawsOk &= !derawFile.exists();
             }
