@@ -45,7 +45,7 @@ class FTPlugin : public DPluginGeneric
 
 public:
 
-    explicit FTPlugin(QObject* const parent = 0);
+    explicit FTPlugin(QObject* const parent = nullptr);
     ~FTPlugin();
 
     QString name()                 const override;
@@ -56,6 +56,7 @@ public:
     QList<DPluginAuthor> authors() const override;
 
     void setup(QObject* const) override;
+    void cleanUp()             override;
 
 private Q_SLOTS:
 
