@@ -44,6 +44,7 @@
 
 // KDE includes
 
+#include <klocalizedstring.h>
 #include <kwindowconfig.h>
 
 // Local includes
@@ -96,11 +97,11 @@ public:
 
         state        = P_USERNAME;
 
-        parent       = 0;
-        netMngr      = 0;
-        reply        = 0;
-        settings     = 0;
-        view         = 0;
+        parent       = nullptr;
+        netMngr      = nullptr;
+        reply        = nullptr;
+        settings     = nullptr;
+        view         = nullptr;
     }
 
 public:
@@ -299,7 +300,7 @@ void PTalker::cancel()
     if (d->reply)
     {
         d->reply->abort();
-        d->reply = 0;
+        d->reply = nullptr;
     }
 
     emit signalBusy(false);
@@ -353,7 +354,7 @@ bool PTalker::addPin(const QString& imgPath, const QString& uploadBoard, bool re
     if (d->reply)
     {
         d->reply->abort();
-        d->reply = 0;
+        d->reply = nullptr;
     }
 
     emit signalBusy(true);
@@ -441,7 +442,7 @@ void PTalker::slotFinished(QNetworkReply* reply)
         return;
     }
 
-    d->reply = 0;
+    d->reply = nullptr;
 
     if (reply->error() != QNetworkReply::NoError)
     {
