@@ -44,7 +44,7 @@ class SmugPlugin : public DPluginGeneric
 
 public:
 
-    explicit SmugPlugin(QObject* const parent = 0);
+    explicit SmugPlugin(QObject* const parent = nullptr);
     ~SmugPlugin();
 
     QString name()                 const override;
@@ -55,6 +55,7 @@ public:
     QList<DPluginAuthor> authors() const override;
 
     void setup(QObject* const) override;
+    void cleanUp()             override;
 
 private Q_SLOTS:
 
