@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-04-02
  * Description : Core database file name filters based on file suffixes.
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,8 +23,8 @@
  *
  * ============================================================ */
 
-#ifndef CORE_DATABASE_NAMEFILTER_H
-#define CORE_DATABASE_NAMEFILTER_H
+#ifndef DIGIKAM_CORE_DB_NAME_FILTER_H
+#define DIGIKAM_CORE_DB_NAME_FILTER_H
 
 // Qt includes
 
@@ -61,6 +61,6 @@ protected:
     QList<QRegExp> m_filterList;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif // CORE_DATABASE_NAMEFILTER_H
+#endif // DIGIKAM_CORE_DB_NAME_FILTER_H
