@@ -244,7 +244,7 @@ DConfigDlgTabbedView::~DConfigDlgTabbedView()
             if (page)
             {
                 page->setVisible(false);
-                page->setParent(0); // reparent our children before they are deleted
+                page->setParent(nullptr); // reparent our children before they are deleted
             }
         }
     }
