@@ -45,6 +45,7 @@
 
 // KDE includes
 
+#include <kconfiggroup.h>
 #include <klocalizedstring.h>
 
 // Local includes
@@ -56,8 +57,6 @@
 #include "dcombobox.h"
 #include "colorgradientwidget.h"
 
-
-
 namespace Digikam
 {
 
@@ -68,7 +67,7 @@ public:
 
     explicit Private()
       : histoSegments(0),
-        curvesBox(0)
+        curvesBox(nullptr)
     {
     }
 
