@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2004-12-01
  * Description : image curves manipulation methods.
  *
- * Copyright (C) 2004-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IMAGECURVES_H
-#define IMAGECURVES_H
+#ifndef DIGIKAM_IMAGE_CURVES_H
+#define DIGIKAM_IMAGE_CURVES_H
 
 // Qt includes
 
@@ -109,6 +109,8 @@ public:
     void   setCurvePoints(int channel, const QPolygon& vals);
     void   setCurveValues(int channel, const QPolygon& vals);
 
+    void   unsetCurvePoint(int channel, int point);
+
     // Properties.
 
     bool   isDirty()                                     const;
@@ -179,6 +181,6 @@ private:
     QSharedDataPointer<Private> d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* IMAGECURVES_H */
+#endif // DIGIKAM_IMAGE_CURVES_H
