@@ -27,12 +27,27 @@
 #include <QString>
 #include <QtConcurrent>    // krazy:exclude=includes
 
+// KDE includes
+
+#include <klocalizedstring.h>
+
 // Local includes
 
 #include "digikam_debug.h"
 #include "lensfuniface.h"
 #include "dmetadata.h"
 
+// Disable deprecated API from Lensfun.
+#if defined(Q_CC_GNU)
+#   pragma GCC diagnostic push
+#   pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
 namespace Digikam
 {
 
@@ -64,7 +79,9 @@ LensFunFilter::LensFunFilter(QObject* const parent)
     initFilter();
 }
 
-LensFunFilter::LensFunFilter(DImg* const orgImage, QObject* const parent,  const LensFunContainer& settings)
+LensFunFilter::LensFunFilter(DImg* const orgImage,
+                             QObject* const parent,
+                             const LensFunContainer& settings)
     : DImgThreadedFilter(orgImage, parent, QLatin1String("LensCorrection")),
       d(new Private)
 {
@@ -86,6 +103,11 @@ LensFunFilter::~LensFunFilter()
     delete d;
 }
 
+QString LensFunFilter::DisplayableName()
+{
+    return QString::fromUtf8(I18N_NOOP("Lens Auto-Correction Tool"));
+}
+
 void LensFunFilter::filterCCAMultithreaded(uint start, uint stop)
 {
     QScopedArrayPointer<float> pos(new float[m_orgImage.width() * 2 * 3]);
@@ -393,3 +415,12 @@ void LensFunFilter::readParameters(const Digikam::FilterAction& action)
 }
 
 } // namespace Digikam
+
+// Restore warnings
+#if defined(Q_CC_GNU)
+#   pragma GCC diagnostic pop
+#endif
+
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic pop
+#endif
