@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2007-16-01
  * Description : white balance color correction.
  *
- * Copyright (C) 2007-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008      by Guillaume Castagnino <casta at xwing dot info>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -42,10 +42,6 @@ WBContainer::WBContainer()
     dark           = 0.5;
     gamma          = 1.0;
     saturation     = 1.0;
-
-    maxr           = -1;
-    maxg           = -1;
-    maxb           = -1;
 }
 
 bool WBContainer::isDefault() const
@@ -91,4 +87,4 @@ WBContainer WBContainer::fromFilterAction(const FilterAction& action, const QStr
     return settings;
 }
 
-}  // namespace Digikam
+} // namespace Digikam
