@@ -41,6 +41,7 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "digikam_config.h"
 #include "digikam_version.h"
 
 namespace Digikam
@@ -77,20 +78,29 @@ QFileInfoList DPluginLoader::Private::pluginEntriesList() const
 
     qCDebug(DIGIKAM_GENERAL_LOG) << "Parsing plugins from" << path;
 
-    QDirIterator  it(path, QDir::Files |
-                           QDir::NoDotAndDotDot,
-                           QDirIterator::Subdirectories);
+#ifdef Q_OS_OSX
+    QString filter(QLatin1String("*.dylib *.so"));
+#elif defined Q_OS_WIN
+    QString filter(QLatin1String("*.dll"));
+#else
+    QString filter(QLatin1String("*.so"));
+#endif
+
+    QDir dir(path, filter, QDir::Unsorted,
+             QDir::Files | QDir::NoDotAndDotDot);
+
+    QDirIterator  it(dir, QDirIterator::Subdirectories);
     QFileInfoList allFiles;
     QStringList   dupFiles;
 
     while (it.hasNext())
     {
-        QFileInfo info(it.next());
+        it.next();
 
-        if (!dupFiles.contains(info.baseName()))
+        if (!dupFiles.contains(it.fileInfo().baseName()))
         {
-            dupFiles << info.baseName();
-            allFiles << info;
+            dupFiles << it.fileInfo().baseName();
+            allFiles << it.fileInfo();
         }
     }
 
@@ -122,7 +132,6 @@ bool DPluginLoader::Private::appendPlugin(QObject* const obj,
             plugin->setLibraryFileName(loader->fileName());
 
             allPlugins << plugin;
-            allLoaders << loader;
 
             return true;
         }
@@ -142,7 +151,7 @@ void DPluginLoader::Private::loadPlugins()
     t.start();
     qCDebug(DIGIKAM_GENERAL_LOG) << "Starting to load external tools.";
 
-    Q_ASSERT(allPlugins.isEmpty() && allLoaders.isEmpty());
+    Q_ASSERT(allPlugins.isEmpty());
 
     for (const QFileInfo& info : pluginEntriesList())
     {
