@@ -71,7 +71,7 @@ public:
                 properties << *it;
             }
         }
-        catch( Exiv2::Error& e )
+        catch(Exiv2::AnyError& e)
         {
             MetaEngine::Private::printExiv2ExceptionError(QLatin1String("Cannot load preview data using Exiv2 "), e);
         }
@@ -102,7 +102,7 @@ MetaEnginePreviews::MetaEnginePreviews(const QString& filePath)
         d->load(image);
 #endif
     }
-    catch( Exiv2::Error& e )
+    catch(Exiv2::AnyError& e)
     {
         MetaEngine::Private::printExiv2ExceptionError(QLatin1String("Cannot load metadata using Exiv2 "), e);
     }
@@ -126,7 +126,7 @@ MetaEnginePreviews::MetaEnginePreviews(const QByteArray& imgData)
         d->load(image);
 #endif
     }
-    catch( Exiv2::Error& e )
+    catch(Exiv2::AnyError& e)
     {
         MetaEngine::Private::printExiv2ExceptionError(QLatin1String("Cannot load metadata using Exiv2 "), e);
     }
@@ -206,8 +206,8 @@ QByteArray MetaEnginePreviews::data(int index)
 {
     if (index < 0 || index >= size()) return QByteArray();
 
-    qCDebug(DIGIKAM_METAENGINE_LOG) << "index: "         << index;
-    qCDebug(DIGIKAM_METAENGINE_LOG) << "d->properties: " << count();
+    qCDebug(DIGIKAM_METAENGINE_LOG) << "index     : " << index;
+    qCDebug(DIGIKAM_METAENGINE_LOG) << "properties: " << count();
 
     QMutexLocker lock(&s_metaEngineMutex);
 
@@ -216,7 +216,7 @@ QByteArray MetaEnginePreviews::data(int index)
         Exiv2::PreviewImage image = d->manager->getPreviewImage(d->properties[index]);
         return QByteArray((const char*)image.pData(), image.size());
     }
-    catch( Exiv2::Error& e )
+    catch(Exiv2::AnyError& e)
     {
         MetaEngine::Private::printExiv2ExceptionError(QLatin1String("Cannot load metadata using Exiv2 "), e);
         return QByteArray();
