@@ -49,7 +49,7 @@ public:
         : q(q)
     {
         // Note: Don't make the mutex recursive, we need to use a wait condition on it
-        watch = 0;
+        watch = nullptr;
     }
 
     void mapImageFilePath(const QString& filePath, const QString& cacheKey);
@@ -142,7 +142,7 @@ void LoadingCache::Private::cleanUpThumbnailFilePathHash()
     }
 }
 
-LoadingCache* LoadingCache::m_instance = 0;
+LoadingCache* LoadingCache::m_instance = nullptr;
 
 LoadingCache* LoadingCache::cache()
 {
@@ -179,7 +179,7 @@ LoadingCache::~LoadingCache()
 {
     delete d->watch;
     delete d;
-    m_instance = 0;
+    m_instance = nullptr;
 }
 
 DImg* LoadingCache::retrieveImage(const QString& cacheKey) const
@@ -266,7 +266,11 @@ bool LoadingCache::hasThumbnailPixmap(const QString& cacheKey) const
 
 void LoadingCache::putThumbnail(const QString& cacheKey, const QImage& thumb, const QString& filePath)
 {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+    int cost = thumb.sizeInBytes();
+#else
     int cost = thumb.byteCount();
+#endif
 
     if (d->thumbnailImageCache.insert(cacheKey, new QImage(thumb), cost))
     {
@@ -300,8 +304,13 @@ void LoadingCache::removeThumbnails()
 
 void LoadingCache::setThumbnailCacheSize(int numberOfQImages, int numberOfQPixmaps)
 {
-    d->thumbnailImageCache.setMaxCost(numberOfQImages * ThumbnailSize::maxThumbsSize() * ThumbnailSize::maxThumbsSize() * 4);
-    d->thumbnailPixmapCache.setMaxCost(numberOfQPixmaps * ThumbnailSize::maxThumbsSize() * ThumbnailSize::maxThumbsSize() * QPixmap::defaultDepth() / 8);
+    d->thumbnailImageCache.setMaxCost(numberOfQImages *
+                                      ThumbnailSize::maxThumbsSize() *
+                                      ThumbnailSize::maxThumbsSize() * 4);
+
+    d->thumbnailPixmapCache.setMaxCost(numberOfQPixmaps *
+                                       ThumbnailSize::maxThumbsSize() *
+                                       ThumbnailSize::maxThumbsSize() * QPixmap::defaultDepth() / 8);
 }
 
 void LoadingCache::setFileWatch(LoadingCacheFileWatch* const watch)
@@ -311,6 +320,11 @@ void LoadingCache::setFileWatch(LoadingCacheFileWatch* const watch)
     d->watch->m_cache = this;
 }
 
+void LoadingCache::removeFromFileWatch(const QString& filePath)
+{
+    d->fileWatch()->removeFile(filePath);
+}
+
 QStringList LoadingCache::imageFilePathsInCache() const
 {
     d->cleanUpImageFilePathHash();
@@ -329,23 +343,15 @@ void LoadingCache::notifyFileChanged(const QString& filePath, bool notify)
 
     foreach (const QString& cacheKey, keys)
     {
-        if (d->imageCache.remove(cacheKey) && notify)
-        {
-            emit fileChanged(filePath, cacheKey);
-        }
+        d->imageCache.remove(cacheKey);
     }
 
     keys = d->thumbnailFilePathHash.values(filePath);
 
     foreach (const QString& cacheKey, keys)
     {
-        bool removedImage  = d->thumbnailImageCache.remove(cacheKey);
-        bool removedPixmap = d->thumbnailPixmapCache.remove(cacheKey);
-
-        if ((removedImage || removedPixmap) && notify)
-        {
-            emit fileChanged(filePath, cacheKey);
-        }
+        d->thumbnailImageCache.remove(cacheKey);
+        d->thumbnailPixmapCache.remove(cacheKey);
     }
 
     if (notify)
@@ -376,7 +382,7 @@ LoadingCacheFileWatch::~LoadingCacheFileWatch()
 
         if (m_cache->d->watch == this)
         {
-            m_cache->d->watch = 0;
+            m_cache->d->watch = nullptr;
         }
     }
 }
@@ -390,6 +396,11 @@ void LoadingCacheFileWatch::notifyFileChanged(const QString& filePath)
     }
 }
 
+void LoadingCacheFileWatch::removeFile(const QString&)
+{
+    // default: do nothing
+}
+
 void LoadingCacheFileWatch::addedImage(const QString&)
 {
     // default: do nothing
@@ -420,7 +431,6 @@ ClassicLoadingCacheFileWatch::ClassicLoadingCacheFileWatch()
     connect(this, SIGNAL(signalUpdateDirWatch()),
             this, SLOT(slotUpdateDirWatch()),
             Qt::QueuedConnection);
-
 }
 
 ClassicLoadingCacheFileWatch::~ClassicLoadingCacheFileWatch()
@@ -428,6 +438,11 @@ ClassicLoadingCacheFileWatch::~ClassicLoadingCacheFileWatch()
     delete m_watch;
 }
 
+void ClassicLoadingCacheFileWatch::removeFile(const QString& filePath)
+{
+    m_watch->removePath(filePath);
+}
+
 void ClassicLoadingCacheFileWatch::addedImage(const QString& filePath)
 {
     Q_UNUSED(filePath)
@@ -445,12 +460,11 @@ void ClassicLoadingCacheFileWatch::addedThumbnail(const QString& filePath)
 void ClassicLoadingCacheFileWatch::slotFileDirty(const QString& path)
 {
     // Signal comes from main thread
-    qCDebug(DIGIKAM_GENERAL_LOG) << "LoadingCache slotFileDirty " << path;
+    qCDebug(DIGIKAM_GENERAL_LOG) << "LoadingCache slotFileDirty:" << path;
     // This method acquires a lock itself
     notifyFileChanged(path);
     // No need for locking here, we are in main thread
     m_watch->removePath(path);
-    m_watchedFiles.remove(path);
 }
 
 void ClassicLoadingCacheFileWatch::slotUpdateDirWatch()
@@ -459,41 +473,35 @@ void ClassicLoadingCacheFileWatch::slotUpdateDirWatch()
     LoadingCache::CacheLock lock(m_cache);
 
     // get a list of files in cache that need watch
-    QSet<QString> toBeAdded;
-    QSet<QString> toBeRemoved = m_watchedFiles;
-    QList<QString> filePaths  = m_cache->imageFilePathsInCache();
+    QStringList watchedFiles = m_watch->files();
+    QList<QString> filePaths = m_cache->imageFilePathsInCache();
 
-    foreach (const QString& m_watchPath, filePaths)
+    foreach (const QString& path, watchedFiles)
     {
-        if (!m_watchPath.isEmpty())
+        if (!path.isEmpty())
         {
-            if (!m_watchedFiles.contains(m_watchPath))
+            if (!filePaths.contains(path))
             {
-                toBeAdded.insert(m_watchPath);
+                m_watch->removePath(path);
             }
-
-            toBeRemoved.remove(m_watchPath);
         }
     }
 
-    foreach (const QString& watchedItem, toBeRemoved)
+    foreach (const QString& path, filePaths)
     {
-        //qCDebug(DIGIKAM_GENERAL_LOG) << "removing watch for " << *it;
-        m_watch->removePath(watchedItem);
-        m_watchedFiles.remove(watchedItem);
-    }
-
-    foreach (const QString& watchedItem, toBeAdded)
-    {
-        //qCDebug(DIGIKAM_GENERAL_LOG) << "adding watch for " << *it;
-        m_watch->addPath(watchedItem);
-        m_watchedFiles.insert(watchedItem);
+        if (!path.isEmpty())
+        {
+            if (!watchedFiles.contains(path))
+            {
+                m_watch->addPath(path);
+            }
+        }
     }
 }
 
 //---------------------------------------------------------------------------------------------------
 
-LoadingCache::CacheLock::CacheLock(LoadingCache* cache)
+LoadingCache::CacheLock::CacheLock(LoadingCache* const cache)
     : m_cache(cache)
 {
     m_cache->d->mutex.lock();
