@@ -205,56 +205,59 @@ void SharedLoadingTask::execute()
 
         m_img = DImg(m_loadingDescription.filePath, this, m_loadingDescription.rawDecodingSettings);
 
+        if (continueQuery(&m_img))
         {
-            LoadingCache::CacheLock lock(cache);
-
-            // put (valid) image into cache of loaded images
-            if (continueQuery(&m_img) && !m_img.isNull())
             {
-                cache->putImage(m_loadingDescription.cacheKey(), m_img,
-                                m_loadingDescription.filePath);
-            }
+                LoadingCache::CacheLock lock(cache);
 
-            // remove this from the list of loading processes in cache
-            cache->removeLoadingProcess(this);
-        }
-
-        {
-            LoadingCache::CacheLock lock(cache);
-
-            // indicate that loading has finished so that listeners can stop waiting
-            m_completed = true;
-
-            // dispatch image to all listeners, including this
-            for (int i = 0 ; i < m_listeners.count() ; ++i)
-            {
-                LoadingProcessListener* const l = m_listeners.at(i);
-
-                if (l->accessMode() == LoadSaveThread::AccessModeReadWrite)
+                // put (valid) image into cache of loaded images
+                if (!m_img.isNull())
                 {
-                    // If a listener requested ReadWrite access, it gets a deep copy.
-                    // DImg is explicitly shared.
-                    l->setResult(m_loadingDescription, m_img.copy());
-                }
-                else
-                {
-                    l->setResult(m_loadingDescription, m_img);
+                    cache->putImage(m_loadingDescription.cacheKey(), m_img,
+                                    m_loadingDescription.filePath);
                 }
+
+                // remove this from the list of loading processes in cache
+                cache->removeLoadingProcess(this);
             }
 
-            // remove myself from list of listeners
-            removeListener(this);
-            // wake all listeners waiting on cache condVar, so that they remove themselves
-            lock.wakeAll();
-
-            // wait until all listeners have removed themselves
-            while (m_listeners.count() != 0)
             {
-                lock.timedWait();
-            }
+                LoadingCache::CacheLock lock(cache);
 
-            // set to 0, as checked in setStatus
-            m_usedProcess = nullptr;
+                // indicate that loading has finished so that listeners can stop waiting
+                m_completed = true;
+
+                // dispatch image to all listeners, including this
+                for (int i = 0 ; i < m_listeners.count() ; ++i)
+                {
+                    LoadingProcessListener* const l = m_listeners.at(i);
+
+                    if (l->accessMode() == LoadSaveThread::AccessModeReadWrite)
+                    {
+                        // If a listener requested ReadWrite access, it gets a deep copy.
+                        // DImg is explicitly shared.
+                        l->setResult(m_loadingDescription, m_img.copy());
+                    }
+                    else
+                    {
+                        l->setResult(m_loadingDescription, m_img);
+                    }
+                }
+
+                // remove myself from list of listeners
+                removeListener(this);
+                // wake all listeners waiting on cache condVar, so that they remove themselves
+                lock.wakeAll();
+
+                // wait until all listeners have removed themselves
+                while (m_listeners.count() != 0)
+                {
+                    lock.timedWait();
+                }
+
+                // set to 0, as checked in setStatus
+                m_usedProcess = nullptr;
+            }
         }
     }
 
@@ -386,6 +389,8 @@ void SharedLoadingTask::setStatus(LoadingTaskStatus status)
         // check for m_usedProcess, to avoid race condition that it has finished before
         if (m_usedProcess)
         {
+            // remove this from the list of loading processes in cache
+            cache->removeLoadingProcess(this); 
             // remove this from list of listeners - check in continueQuery() of active thread
             m_usedProcess->removeListener(this);
             // set m_usedProcess to 0, signalling that we have detached already
@@ -429,7 +434,7 @@ void SharedLoadingTask::notifyNewLoadingProcess(LoadingProcess* const process, c
     // In this case, we notify our own thread (a signal to the API user is emitted) of this.
     // The fact that we are receiving the method call shows that this task is registered with the LoadingCache,
     // somewhere in between the calls to addLoadingProcess(this) and removeLoadingProcess(this) above.
-    if (process != dynamic_cast<LoadingProcess*>(this)               &&
+    if (process != static_cast<LoadingProcess*>(this)                &&
         m_loadingDescription.isReducedVersion()                      &&
         m_loadingDescription.equalsIgnoreReducedVersion(description) &&
         !description.isReducedVersion())
