@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2017-05-24
  * Description : images transition manager.
  *
- * Copyright (C) 2017 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2017-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -20,8 +20,8 @@
  *
  * ============================================================ */
 
-#ifndef TRANSITION_MNGR_H
-#define TRANSITION_MNGR_H
+#ifndef DIGIKAM_TRANSITION_MNGR_H
+#define DIGIKAM_TRANSITION_MNGR_H
 
 // Qt includes
 
@@ -89,10 +89,12 @@ public:
 
 private:
 
+    TransitionMngr(const TransitionMngr&); // Disable
+
     class Private;
     Private* const d;
 };
 
 } // namespace Digikam
 
-#endif // TRANSITION_MNGR_H
+#endif // DIGIKAM_TRANSITION_MNGR_H
