@@ -50,7 +50,7 @@ public:
 
 public:
 
-    explicit DFontSelect(const QString& text, QWidget* const parent=0);
+    explicit DFontSelect(const QString& text, QWidget* const parent=nullptr);
     virtual ~DFontSelect();
 
     void setMode(FontMode mode);
@@ -65,7 +65,7 @@ Q_SIGNALS:
 
 protected:
 
-    bool event(QEvent* e);
+    bool event(QEvent* e) override;
 
 private Q_SLOTS:
 
