@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2013-12-20
  * Description : Settings for Showfoto
  *
- * Copyright (C) 2013-2014 by Mohamed Anwer <m dot anwer at gmx dot com>
- * Copyright (C) 2013-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * Copyright (C) 2013-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTOSETTINGS_H
-#define SHOWFOTOSETTINGS_H
+#ifndef SHOW_FOTO_SETTINGS_H
+#define SHOW_FOTO_SETTINGS_H
 
 // Qt includes
 
@@ -65,6 +65,9 @@ public:
     QString getIconTheme() const;
     void setIconTheme(const QString& theme);
 
+    void setApplicationFont(const QFont& fnt);
+    QFont getApplicationFont() const;
+
     bool getShowFormatOverThumbnail() const;
     void setShowFormatOverThumbnail(bool show);
 
@@ -148,6 +151,6 @@ private:
     friend class ShowfotoSettingsCreator;
 };
 
-} // namespace Digikam
+} // namespace Showfoto
 
-#endif // SHOWFOTOSETTINGS_H
+#endif // SHOW_FOTO_SETTINGS_H
