@@ -89,14 +89,14 @@ public:
      *  If it still needs to be loaded, returns a null QVariant and emits
      *  thumbnailAvailable() as soon as it is available.
      */
-    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
+    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
 
     /**
      * You can override the current thumbnail size by giving an integer value for ThumbnailRole.
      * Set a null QVariant to use the thumbnail size set by setThumbnailSize() again.
      * The index given here is ignored for this purpose.
      */
-    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::DisplayRole);
+    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::DisplayRole) override;
 
     bool pixmapForItem(QString url, QPixmap& pix) const;
     bool getThumbnail(const ShowfotoItemInfo& itemInfo, QImage& thumbnail) const;
