@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-05-12
  * Description : Test parsing rg data.
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef TEST_RGPARSING_H
-#define TEST_RGPARSING_H
+#ifndef DIGIKAM_TEST_RGPARSING_H
+#define DIGIKAM_TEST_RGPARSING_H
 
 // Qt includes
 
@@ -39,4 +39,4 @@ private Q_SLOTS:
     void testVerifyRG();
 };
 
-#endif /* TEST_RGPARSING_H */
+#endif /* DIGIKAM_TEST_RGPARSING_H */
