@@ -103,7 +103,7 @@ class MainWindow : public QMainWindow
 
 public:
 
-    explicit MainWindow(QCommandLineParser* const cmdLineArgs, QWidget* const parent = 0);
+    explicit MainWindow(QCommandLineParser* const cmdLineArgs, QWidget* const parent = nullptr);
     ~MainWindow();
 
 public Q_SLOTS:
@@ -114,7 +114,7 @@ protected:
 
     void readSettings();
     void saveSettings();
-    void closeEvent(QCloseEvent* e);
+    void closeEvent(QCloseEvent* e) override;
     void createMenus();
 
 private Q_SLOTS:
