@@ -61,7 +61,12 @@ struct SortByDate
     {
         QFileInfo fi1(s1);
         QFileInfo fi2(s2);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+        return fi1.birthTime() < fi2.birthTime();
+#else
         return fi1.created() < fi2.created();
+#endif
     }
 };
 
@@ -80,8 +85,8 @@ class Q_DECL_HIDDEN AdvancedRenameManager::Private
 public:
 
     explicit Private()
-      : parser(0),
-        widget(0),
+      : parser(nullptr),
+        widget(nullptr),
         parserType(AdvancedRenameManager::DefaultParser),
         sortAction(AdvancedRenameManager::SortCustom),
         sortDirection(AdvancedRenameManager::SortAscending),
@@ -176,7 +181,7 @@ void AdvancedRenameManager::setWidget(AdvancedRenameWidget* widget)
 {
     if (!widget)
     {
-        d->widget = 0;
+        d->widget = nullptr;
         return;
     }
 
@@ -468,19 +473,29 @@ int AdvancedRenameManager::indexOfFileGroup(const QString& filename)
 
 QString AdvancedRenameManager::newName(const QString& filename) const
 {
-    // For the Windows file system, we need to replace unsupported characters.
+    // For the Linux or Windows file system,
+    // we need to replace unsupported characters.
     QStorageInfo info(QFileInfo(filename).path());
 
-    QString newName = d->renamedFiles.value(filename, filename);
-    QString sysType = QString::fromLatin1(info.fileSystemType()).toUpper();
+    QString regExpStr = QLatin1String("[?*");
+    QString newName   = d->renamedFiles.value(filename, filename);
+    QString sysType   = QString::fromLatin1(info.fileSystemType()).toUpper();
 
-    if (sysType.contains(QLatin1String("FAT")) ||
-        sysType.contains(QLatin1String("NTFS")))
+    if (sysType.contains(QLatin1String("FAT"))  ||
+        sysType.contains(QLatin1String("NTFS")) ||
+        sysType.contains(QLatin1String("FUSEBLK")))
     {
-        QRegExp regexp(QLatin1String("[?*<>,\\+:=/\";|]"));
-        newName.replace(regexp, QLatin1String("_"));
+        regExpStr.append(QLatin1String("<>,:=\";|\\\\/"));
+
+        if (sysType.contains(QLatin1String("FAT")))
+        {
+            regExpStr.append(QLatin1Char('+'));
+        }
     }
 
+    QRegExp regExp(regExpStr + QLatin1Char(']'));
+    newName.replace(regExp, QLatin1String("_"));
+
     return newName;
 }
 
