@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2010-05-22
  * Description : a parser for the AdvancedRename utility used for importing images,
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef IMPORTRENAMEPARSER_H
-#define IMPORTRENAMEPARSER_H
+#ifndef DIGIKAM_IMPORT_RENAME_PARSER_H
+#define DIGIKAM_IMPORT_RENAME_PARSER_H
 
 // Local includes
 
@@ -37,7 +37,7 @@ class ImportRenameParser : public Parser
 
 public:
 
-    ImportRenameParser();
+    explicit ImportRenameParser();
 
 private:
 
@@ -45,7 +45,6 @@ private:
     ImportRenameParser& operator=(const ImportRenameParser&);
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-
-#endif /* IMPORTRENAMEPARSER_H */
+#endif // DIGIKAM_IMPORT_RENAME_PARSER_H
