@@ -35,6 +35,7 @@
 #include <QLabel>
 #include <QApplication>
 #include <QStyle>
+#include <QTimer>
 
 // KDE includes
 
@@ -68,19 +69,19 @@ public:
 
     explicit Private()
     {
-        includeAlbumsLabel      = 0;
-        listView                = 0;
-        scanDuplicatesBtn       = 0;
-        updateFingerPrtBtn      = 0;
-        progressItem            = 0;
-        similarityLabel         = 0;
-        similarityRange         = 0;
-        restrictResultsLabel    = 0;
-        albumTagRelationLabel   = 0;
-        searchResultRestriction = 0;
-        albumTagRelation        = 0;
-        albumSelectors          = 0;
-        settings                = 0;
+        includeAlbumsLabel      = nullptr;
+        listView                = nullptr;
+        scanDuplicatesBtn       = nullptr;
+        updateFingerPrtBtn      = nullptr;
+        progressItem            = nullptr;
+        similarityLabel         = nullptr;
+        similarityRange         = nullptr;
+        restrictResultsLabel    = nullptr;
+        albumTagRelationLabel   = nullptr;
+        searchResultRestriction = nullptr;
+        albumTagRelation        = nullptr;
+        albumSelectors          = nullptr;
+        settings                = nullptr;
         active                  = false;
     }
 
@@ -234,9 +235,6 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
     connect(d->albumSelectors, SIGNAL(signalSelectionChanged()),
             this, SLOT(slotCheckForValidSettings()));
 
-    connect(AlbumManager::instance(), SIGNAL(signalAllAlbumsLoaded()),
-            this, SLOT(populateTreeView()));
-
     connect(AlbumManager::instance(), SIGNAL(signalAllAlbumsLoaded()),
             this, SLOT(initAlbumUpdateConnections()));
 
@@ -271,10 +269,21 @@ void FindDuplicatesView::initAlbumUpdateConnections()
 void FindDuplicatesView::setActive(bool val)
 {
     d->active = val;
+    QTimer::singleShot(250, this, SLOT(slotSelectFirstItem()));
 }
 
 void FindDuplicatesView::populateTreeView()
 {
+    if (d->listView->topLevelItemCount() > 0)
+    {
+        return;
+    }
+
+    QTime waitCursorTime;
+    waitCursorTime.start();
+
+    bool waitCursor = false;
+
     const AlbumList& aList = AlbumManager::instance()->allSAlbums();
 
     for (AlbumList::const_iterator it = aList.constBegin() ; it != aList.constEnd() ; ++it)
@@ -286,15 +295,30 @@ void FindDuplicatesView::populateTreeView()
             FindDuplicatesAlbumItem* const item = new FindDuplicatesAlbumItem(d->listView, salbum);
             salbum->setExtraData(this, item);
         }
+
+        if (!waitCursor && waitCursorTime.elapsed() > 2000)
+        {
+            QApplication::setOverrideCursor(Qt::WaitCursor);
+            waitCursor = true;
+        }
     }
 
     d->listView->setSortingEnabled(true);
-    d->listView->sortByColumn(1, Qt::DescendingOrder);
     d->listView->resizeColumnToContents(0);
+    d->listView->sortByColumn(1, Qt::DescendingOrder);
 
     d->albumSelectors->loadState();
 
+    if (waitCursor)
+    {
+        QApplication::restoreOverrideCursor();
+    }
+}
+
+void FindDuplicatesView::slotSelectFirstItem()
+{
     d->listView->selectFirstItem();
+    slotDuplicatesAlbumActived();
 }
 
 QList<SAlbum*> FindDuplicatesView::currentFindDuplicatesAlbums() const
@@ -420,8 +444,8 @@ void FindDuplicatesView::enableControlWidgets(bool val)
 void FindDuplicatesView::slotFindDuplicates()
 {
     d->albumSelectors->saveState();
-    slotClear();
     enableControlWidgets(false);
+    slotClear();
 
     AlbumList albums;
     AlbumList tags;
@@ -443,6 +467,8 @@ void FindDuplicatesView::slotFindDuplicates()
         tags   = d->albumSelectors->selectedTags();
     }
 
+    AlbumManager::instance()->clearCurrentAlbums();
+
     DuplicatesFinder* const finder = new DuplicatesFinder(albums, tags,
                                                           d->albumTagRelation->itemData(d->albumTagRelation->currentIndex()).toInt(),
                                                           d->similarityRange->minValue(), d->similarityRange->maxValue(),
@@ -470,6 +496,8 @@ void FindDuplicatesView::slotComplete()
     enableControlWidgets(true);
     slotCheckForValidSettings();
     populateTreeView();
+
+    QTimer::singleShot(250, this, SLOT(slotSelectFirstItem()));
 }
 
 void FindDuplicatesView::slotDuplicatesAlbumActived()
@@ -521,7 +549,14 @@ void FindDuplicatesView::slotSetSelectedAlbum(PAlbum* album)
     // @ODD : Why is singleton set to true? resetAlbumsAndTags already clears the selection.
     d->albumSelectors->setAlbumSelected(album, true);
     d->albumSelectors->setTypeSelection(AlbumSelectors::AlbumType::PhysAlbum);
+    d->albumTagRelation->setCurrentIndex(d->albumTagRelation->findData(HaarIface::AlbumTagRelation::NoMix));
+    d->searchResultRestriction->setCurrentIndex(d->searchResultRestriction->findData(HaarIface::DuplicatesSearchRestrictions::None));
     slotCheckForValidSettings();
+
+    if (d->scanDuplicatesBtn->isEnabled())
+    {
+        slotFindDuplicates();
+    }
 }
 
 void FindDuplicatesView::slotSetSelectedAlbums(const QList<PAlbum*>& albums)
@@ -535,7 +570,14 @@ void FindDuplicatesView::slotSetSelectedAlbums(const QList<PAlbum*>& albums)
     }
 
     d->albumSelectors->setTypeSelection(AlbumSelectors::AlbumType::PhysAlbum);
+    d->albumTagRelation->setCurrentIndex(d->albumTagRelation->findData(HaarIface::AlbumTagRelation::NoMix));
+    d->searchResultRestriction->setCurrentIndex(d->searchResultRestriction->findData(HaarIface::DuplicatesSearchRestrictions::None));
     slotCheckForValidSettings();
+
+    if (d->scanDuplicatesBtn->isEnabled())
+    {
+        slotFindDuplicates();
+    }
 }
 
 void FindDuplicatesView::slotSetSelectedAlbums(const QList<TAlbum*>& albums)
@@ -548,7 +590,14 @@ void FindDuplicatesView::slotSetSelectedAlbums(const QList<TAlbum*>& albums)
     }
 
     d->albumSelectors->setTypeSelection(AlbumSelectors::AlbumType::TagsAlbum);
+    d->albumTagRelation->setCurrentIndex(d->albumTagRelation->findData(HaarIface::AlbumTagRelation::NoMix));
+    d->searchResultRestriction->setCurrentIndex(d->searchResultRestriction->findData(HaarIface::DuplicatesSearchRestrictions::None));
     slotCheckForValidSettings();
+
+    if (d->scanDuplicatesBtn->isEnabled())
+    {
+        slotFindDuplicates();
+    }
 }
 
 void FindDuplicatesView::resetAlbumsAndTags()
