@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2009-12-01
  * Description : class GroupState
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef GEO_GROUP_STATE_H
-#define GEO_GROUP_STATE_H
+#ifndef DIGIKAM_GEO_GROUP_STATE_H
+#define DIGIKAM_GEO_GROUP_STATE_H
 
 // Qt includes
 
@@ -73,4 +73,4 @@ Q_DECLARE_FLAGS(GeoGroupState, GeoGroupStateEnum)
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::GeoGroupState)
 
-#endif // GEO_GROUP_STATE_H
+#endif // DIGIKAM_GEO_GROUP_STATE_H
