@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2011-04-30
  * Description : Base class for altitude lookup jobs
  *
- * Copyright (C) 2010-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
@@ -22,8 +22,8 @@
  *
  * ============================================================ */
 
-#ifndef LOOKUP_ALTITUDE_H
-#define LOOKUP_ALTITUDE_H
+#ifndef DIGIKAM_LOOKUP_ALTITUDE_H
+#define DIGIKAM_LOOKUP_ALTITUDE_H
 
 // Qt includes
 
@@ -47,10 +47,10 @@ public:
     {
     public:
 
-        Request()
-            : coordinates(),
-              success(false),
-              data()
+        explicit Request()
+          : coordinates(),
+            success(false),
+            data()
         {
         }
 
@@ -99,4 +99,4 @@ Q_SIGNALS:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::LookupAltitude::StatusAltitude)
 
-#endif // LOOKUP_ALTITUDE_H
+#endif // DIGIKAM_LOOKUP_ALTITUDE_H
