@@ -41,7 +41,7 @@ class Q_DECL_HIDDEN AbstractMarkerTiler::Private
 public:
 
     explicit Private()
-        : rootTile(0),
+        : rootTile(nullptr),
           isDirty(true)
     {
     }
@@ -84,7 +84,7 @@ void AbstractMarkerTiler::setDirty(const bool state)
     if (state && !d->isDirty)
     {
         d->isDirty = true;
-        emit(signalTilesOrSelectionChanged());
+        emit signalTilesOrSelectionChanged();
     }
     else
     {
@@ -167,7 +167,7 @@ AbstractMarkerTiler::TilerFlags AbstractMarkerTiler::tilerFlags() const
 void AbstractMarkerTiler::clear()
 {
     tileDelete(d->rootTile);
-    d->rootTile = 0;
+    d->rootTile = nullptr;
 }
 
 // -------------------------------------------------------------------------
@@ -177,7 +177,7 @@ class Q_DECL_HIDDEN AbstractMarkerTiler::NonEmptyIterator::Private
 public:
 
     explicit Private()
-        : model(0),
+        : model(nullptr),
           level(0),
           startIndex(),
           endIndex(),
@@ -543,7 +543,7 @@ AbstractMarkerTiler::Tile* AbstractMarkerTiler::Tile::getChild(const int linearI
 {
     if (children.isEmpty())
     {
-        return 0;
+        return nullptr;
     }
 
     return children.at(linearIndex);
@@ -551,7 +551,7 @@ AbstractMarkerTiler::Tile* AbstractMarkerTiler::Tile::getChild(const int linearI
 
 void AbstractMarkerTiler::Tile::addChild(const int linearIndex, Tile* const tilePointer)
 {
-    if ((tilePointer==0) && children.isEmpty())
+    if ((tilePointer==nullptr) && children.isEmpty())
     {
         return;
     }
