@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of digiKam project
- * http://www.digikam.org
+ * https://www.digikam.org
  *
  * Date        : 2008-08-20
  * Description : Image editor interface used by editor tools.
  *
- * Copyright (C) 2008-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef EDITORTOOLIFACE_H
-#define EDITORTOOLIFACE_H
+#ifndef DIGIKAM_IMAGE_EDITOR_TOOL_IFACE_H
+#define DIGIKAM_IMAGE_EDITOR_TOOL_IFACE_H
 
 // Qt includes
 
@@ -91,6 +91,6 @@ private:
     Private* const d;
 };
 
-}  // namespace Digikam
+} // namespace Digikam
 
-#endif /* EDITORTOOLIFACE_H */
+#endif // DIGIKAM_IMAGE_EDITOR_TOOL_IFACE_H
