@@ -124,7 +124,7 @@ public:
     explicit Private()
         : iconSize(64)
     {
-        ctrl = 0;
+        ctrl = nullptr;
     }
 
     const int         iconSize;
@@ -154,7 +154,7 @@ CameraItemList::~CameraItemList()
 
 void CameraItemList::setItems(const CamItemInfoList& items)
 {
-    foreach(CamItemInfo info, items)
+    foreach (const CamItemInfo& info, items)
     {
         new CameraItem(this, info);
     }
