@@ -117,6 +117,7 @@ urpmi --auto \
       gphoto2-devel \
       sane-backends \
       jasper-devel \
+      ${LIBSUFFIX}xkbcommon-devel \
       ${LIBSUFFIX}sane1-devel \
       ${LIBSUFFIX}xcb-util1 \
       ${LIBSUFFIX}xi-devel \
@@ -135,8 +136,9 @@ urpmi --auto \
       ${LIBSUFFIX}jpeg-devel \
       ${LIBSUFFIX}png-devel \
       ${LIBSUFFIX}tiff-devel \
-      ${LIBSUFFIX}icu-devel \
       ${LIBSUFFIX}lqr-devel \
+      ${LIBSUFFIX}fftw-devel \
+      ${LIBSUFFIX}curl-devel \
       ${LIBSUFFIX}magick-devel
 
 #################################################################################################
@@ -183,6 +185,7 @@ cmake $ORIG_WD/../3rdparty \
 # Low level libraries and Qt5 dependencies
 # NOTE: The order to compile each component here is very important.
 
+#cmake --build . --config RelWithDebInfo --target ext_libicu        -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_qt            -- -j$CPU_CORES    # depend of tiff, png, jpeg
 
 if [[ $DK_QTWEBENGINE = 0 ]] ; then
@@ -193,7 +196,6 @@ cmake --build . --config RelWithDebInfo --target ext_qtav          -- -j$CPU_COR
 
 cmake --build . --config RelWithDebInfo --target ext_exiv2         -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_opencv        -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_lensfun       -- -j$CPU_CORES
 
 #################################################################################################
 
