@@ -1,5 +1,7 @@
 #!/bin/bash
 
+# Configuration for script to build AppImage bundle.
+#
 # Copyright (c) 2015-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
@@ -22,9 +24,7 @@ APP_IMG_DIR="/digikam.appdir"
 ########################################################################
 
 # URL to git repository to checkout digiKam source code
-# Read/write url is an alternative when official read only server is down.
-#DK_GITURL="git://anongit.kde.org/digikam.git"
-DK_GITURL="git@git.kde.org:digikam"
+DK_GITURL="git@invent.kde.org:kde/digikam.git"
 
 # Location to build source code.
 DK_BUILDTEMP=$BUILDING_DIR/dktemp
