@@ -84,7 +84,8 @@ if [ -d "$INSTALL_PREFIX" ] ; then
     if echo "$answer" | grep -iq "^r" ;then
 
         echo "---------- Removing existing $INSTALL_PREFIX"
-        rm -rf "$INSTALL_PREFIX"
+        mv $INSTALL_PREFIX $INSTALL_PREFIX.old
+        rm -rf $INSTALL_PREFIX.old
 
     elif echo "$answer" | grep -iq "^c" ;then
 
@@ -240,21 +241,27 @@ port install \
              libgphoto2 \
              jasper \
              lcms2 \
-             ImageMagick \
              expat \
              libxml2 \
              libxslt \
              libical \
              lensfun \
              bison \
+             x265 \
              ffmpeg \
-             qt511 \
-             qt511-qtimageformats \
-             qt511-qtwebkit \
-             qt511-sqlite-plugin \
-             qt511-mysql-plugin \
-             qt511-qtscript \
-             wget +ssl
+             qt5-qtbase \
+             qt5-qtdeclarative \
+             qt5-qtmacextras \
+             qt5-qtquickcontrols \
+             qt5-qtsvg \
+             qt5-qttools \
+             qt5-qttranslations \
+             qt5-qtimageformats \
+             qt5-qtwebkit \
+             qt5-sqlite-plugin \
+             qt5-mysql-plugin \
+             wget +ssl \
+             ImageMagick
 
 #             sane-backends
 
@@ -286,9 +293,9 @@ cmake $ORIG_WD/../3rdparty \
        -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
        -Wno-dev
 
-cmake --build . --config RelWithDebInfo --target ext_opencv -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_exiv2  -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_qtav   -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_opencv      -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_exiv2       -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_qtav        -- -j$CPU_CORES
 
 #################################################################################################
 
