@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright (c) 2013-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2013-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -117,7 +117,9 @@ OsxCodeName()
 
 MAJOR_OSX_VERSION=$(sw_vers -productVersion | awk -F '.' '{print $1 "." $2}'| cut -d . -f 2)
 
-if [[ $MAJOR_OSX_VERSION == "12" ]]
+if   [[ $MAJOR_OSX_VERSION == "13" ]]
+    then OSX_CODE_NAME="HighSierra"
+elif [[ $MAJOR_OSX_VERSION == "12" ]]
     then OSX_CODE_NAME="Sierra"
 elif [[ $MAJOR_OSX_VERSION == "11" ]]
     then OSX_CODE_NAME="ElCapitan"
@@ -182,3 +184,28 @@ for FILE in ${FILESLIST[@]} ; do
 done
 
 }
+
+########################################################################
+# Automatically register the remote servers has know hosts
+RegisterRemoteServers()
+{
+
+SERVER_LIST="\
+git.kde.org \
+milonia.kde.org \
+"
+
+if [[ ! -f ~/.ssh/known_hosts ]] ; then
+    touch ~/.ssh/known_hosts
+fi
+
+for server in $SERVER_LIST; do
+
+    echo "Register $server"
+
+    ssh-keygen -R $server
+    ssh-keyscan -H $server >> ~/.ssh/known_hosts
+
+done
+
+}
