@@ -3,7 +3,7 @@
 # Script to run all Macports based sub-scripts to build OSX installer.
 # Possible option : "-f" to force operations without to ask confirmation to user.
 #
-# Copyright (c) 2013-2018, Gilles Caulier, <caulier dot gilles at gmail dot com>
+# Copyright (c) 2013-2019, Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
@@ -47,7 +47,7 @@ if [ -d "$INSTALL_PREFIX" ] ; then
     fi
 
     echo "---------- Removing existing Macports build"
-    rm -fr $INSTALL_PREFIX
+    mv $INSTALL_PREFIX $INSTALL_PREFIX.old && rm -fr $INSTALL_PREFIX.old
 
 fi
 
