@@ -128,9 +128,11 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      qttools \
      qtwinextras \
      qtscript \
+     x265 \
      ffmpeg \
      openal \
-     libical
+     libical \
+     imagemagick
 
 echo -e "\n"
 
@@ -174,21 +176,11 @@ ${MXE_BUILD_TARGETS}-cmake $ORIG_WD/../3rdparty \
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_opencv     -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_exiv2      -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_qtav       -- -j$CPU_CORES
-${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_lensfun    -- -j$CPU_CORES
 #${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_libgphoto2 -- -j$CPU_CORES
 ${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_drmingw    -- -j$CPU_CORES
-${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_heif       -- -j$CPU_CORES
 
 #################################################################################################
 
-cd $MXE_BUILDROOT
-
-echo -e "\n"
-echo "---------- Building digiKam extra dependencies with MXE"
-
-make MXE_TARGETS=$MXE_BUILD_TARGETS \
-     imagemagick
-
 export PATH=$ORIG_PATH
 
 TerminateScript
